OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "All contacts" : "Todos os contactos",
    "Details" : "Detalhes",
    "Download picture" : "Transferir imagem",
    "Loading" : "A carregar",
    "Name" : "Nome",
    "Title" : "Título",
    "Download" : "Transferir",
    "Delete" : "Apagar",
    "Groups" : "Grupos",
    "New contact" : "Novo contacto",
    "No results" : "Sem resultados",
    "Last modified" : "Última modificação",
    "Rename" : "Renomear",
    "Enabled" : "Ativada",
    "Disabled" : "Desactivado",
    "Copy link" : "Copiar hiperligação",
    "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
    "can edit" : "pode editar",
    "Importing into" : "Importar para",
    "Import into" : "Importar para",
    "Address book name" : "Nome do livro de endereços",
    "First name" : "Primeiro Nome",
    "Last name" : "Ultimo Nome",
    "Display name" : "Nome de apresentação",
    "Not grouped" : "Não agrupados",
    "Nickname" : "Alcunha",
    "Detailed name" : "Nome em detalhe",
    "Additional names" : "Nomes adicionais",
    "Prefix" : "Prefixo",
    "Suffix" : "Sufixo",
    "Notes" : "Notas",
    "Website" : "Site da Internet",
    "Location" : "Localização:",
    "Federated Cloud ID" : "Id. da Nuvem Federada",
    "Home" : "Início",
    "Work" : "Emprego",
    "Other" : "Outro",
    "Address" : "Endereço",
    "Post office box" : "Apartado",
    "City" : "Cidade",
    "State or province" : "Distrito",
    "Postal code" : "Código Postal",
    "Country" : "País",
    "Birthday" : "Aniversário",
    "Anniversary" : "Aniversário",
    "Date of death" : "Data de falecimento",
    "Email" : "Correio Eletrónico",
    "Instant messaging" : "Mensagens Instantâneas",
    "Phone" : "Telefone",
    "Mobile" : "Telemóvel",
    "Work mobile" : "Telefone de trabalho",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax do emprego",
    "Pager" : "Pager",
    "Voice" : "Voz",
    "Car" : "Carro",
    "Work pager" : "Pager de trabalho",
    "Social network" : "Rede Social",
    "Relationship" : "Relação",
    "Spouse" : "Cônjuge",
    "Child" : "Filho",
    "Mother" : "Mãe",
    "Father" : "Pai",
    "Parent" : "Progenitor",
    "Brother" : "Irmão",
    "Sister" : "Irmã",
    "Relative" : "Parente",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Manager" : "Gestor",
    "Assistant" : "Assistente",
    "Contact" : "Contacto",
    "Gender" : "Género",
    "Female" : "Feminino",
    "Male" : "Masculino",
    "None" : "Nenhum",
    "Unknown" : "Desconhecido",
    "An error occurred" : "Ocorreu um erro"
},
"nplurals=2; plural=(n != 1);");
